@@ -3,17 +3,17 @@
     @Author:            Maxence Larose
 
     @Creation Date:     10/2021
-    @Last modification: 01/2022
+    @Last modification: 03/2022
 
     @Description:       This file contains the class PatientDataQueryStrategies that enumerates the available categories
                         for the queries a user can make to obtain a patient's data.
 """
 
-import enum
+from enum import Enum
 from typing import NamedTuple, Callable
 
 from .factories.patient_data_factories import DefaultPatientDataFactory, SegmentationPatientDataFactory, \
-    SeriesDescriptionPatientDataFactory, SegmentationAndSeriesDescriptionPatientDataFactory
+    SeriesDescriptionPatientDataFactory, SegAndSeriesPatientDataFactory
 
 
 class PatientDataQueryStrategy(NamedTuple):
@@ -21,7 +21,7 @@ class PatientDataQueryStrategy(NamedTuple):
     factory: Callable
 
 
-class PatientDataQueryStrategies(enum.Enum):
+class PatientDataQueryStrategies(Enum):
 
     DEFAULT = PatientDataQueryStrategy(
         name="Default",
@@ -40,5 +40,5 @@ class PatientDataQueryStrategies(enum.Enum):
 
     SEGMENTATION_AND_SERIES_DESCRIPTION = PatientDataQueryStrategy(
         name="Segmentation and series description",
-        factory=SegmentationAndSeriesDescriptionPatientDataFactory
+        factory=SegAndSeriesPatientDataFactory
     )
