@@ -3,19 +3,23 @@
     @Author:            Maxence Larose
 
     @Creation Date:     10/2021
-    @Last modification: 03/2022
+    @Last modification: 10/2022
 
     @Description:       This file contains the PatientDataReader class which is used to read dicom files AND
                         segmentation files.
 """
 
 import logging
-from typing import Dict, List, Optional, Sequence
+from typing import Dict, List, Optional, Union
 
-from dicom2hdf.data_model import ImageDataModel, PatientDataModel, SegmentationDataModel
+from monai.transforms import Compose
+
+from dicom2hdf.data_model import PatientDataModel
 from dicom2hdf.data_readers.image.dicom_reader import DicomReader
 from dicom2hdf.data_readers.patient_data.patient_data_query_context import PatientDataQueryContext
-from dicom2hdf.processing.transforms import BaseTransform
+from dicom2hdf.transforms.history import TransformsHistory
+from dicom2hdf.transforms.transforms import Dicom2hdfTransform
+from dicom2hdf.transforms.utils import apply_transforms
 
 _logger = logging.getLogger(__name__)
 
@@ -166,43 +170,15 @@ class PatientDataReader(DicomReader):
 
         self.failed_images.append(series_key)
 
-    @staticmethod
-    def _apply_transforms(
-            transforms: Sequence[BaseTransform],
-            image: ImageDataModel,
-            segmentations: Sequence[SegmentationDataModel]
-    ):
-        """
-        Apply transforms to image and segmentation.
-
-        Parameters
-        ----------
-        transforms : Sequence[BaseTransform]
-            A sequence of transformations to apply to images and segmentations.
-        image : ImageDataModel
-            The patient's medical image data.
-        segmentations : Sequence[SegmentationDataModel]
-            Data from the segmentation of the patient's medical image.
-        """
-        for transform in transforms:
-            image.simple_itk_image = transform.forward(itk_image=image.simple_itk_image)
-
-            if segmentations:
-                for segmentation_data in segmentations:
-                    for organ_name, label_map in segmentation_data.simple_itk_label_maps.items():
-                        segmentation_data.simple_itk_label_maps[organ_name] = transform.forward(
-                            itk_image=label_map,
-                            segmentation=True
-                        )
-
-    def get_patient_dataset(self, transforms: Optional[Sequence[BaseTransform]]) -> PatientDataModel:
+    def get_patient_dataset(self, transforms: Union[Compose, Dicom2hdfTransform]) -> PatientDataModel:
         """
         Get the patient dataset.
 
         Parameters
         ----------
-        transforms : Optional[Sequence[BaseTransform]]
-            A sequence of transformations to apply to images and segmentations.
+        transforms : Union[Compose, Dicom2hdfTransform]
+            A sequence of transformations to apply to images and segmentations in the physical space, i.e on the
+            SimpleITK image. Keys are assumed to be modality names for images and organ names for segmentations.
 
         Returns
         -------
@@ -226,7 +202,7 @@ class PatientDataReader(DicomReader):
             image = image_and_segmentation_data.image
             segmentations = image_and_segmentation_data.segmentations
 
-            self._apply_transforms(image=image, segmentations=segmentations, transforms=transforms)
+            apply_transforms(image=image, segmentations=segmentations, transforms=transforms)
 
             modality = image.dicom_header.Modality
             series_description = image.dicom_header.SeriesDescription
@@ -245,4 +221,6 @@ class PatientDataReader(DicomReader):
             if image_segmentation_available:
                 _logger.info(f"  Segmented organs : {segmented_organs}")
 
+        patient_dataset.transforms_history = TransformsHistory(transforms)
+
         return patient_dataset
