@@ -7,6 +7,7 @@
 import env_examples  # Modifies path, DO NOT REMOVE
 
 from dicom2hdf import PatientsDataGenerator
+from dicom2hdf.transforms import Compose, ResampleD
 import SimpleITK as sitk
 
 
@@ -16,7 +17,12 @@ if __name__ == "__main__":
     # ----------------------------------------------------------------------------------------------------------- #
     patients_data_generator = PatientsDataGenerator(
         path_to_patients_folder="data/Patients",
-        series_descriptions="data/series_descriptions.json"
+        series_descriptions="data/series_descriptions.json",
+        transforms=Compose(
+            [
+                ResampleD(keys=["CT", "Heart"], out_spacing=(1.5, 1.5, 1.5))
+            ]
+        )
     )
 
     for patient_data in patients_data_generator:
